************
Contributing
************

To contribute to this project, you must follow our :doc:`Code of Conduct </meta/conduct>` at all times.
If you are not familiar with our code of conduct policy, take a minute to read the policy before starting with your first contribution.


How to contribute
-----------------

We welcome contributions of many types, including but not limited to:

    * bug fixes
    * improvements to documentation
    * new features
    * additional examples for using and developing *pyDeltaRCM*

If you are interested in contributing, please submit a pull request or get in touch with the development team via the `Github issue tracker <https://github.com/DeltaRCM/pyDeltaRCM/issues>`_.


Issues and questions
--------------------

If you have identified a bug within the code, but aren't sure how to (or don't want to) fix it, we invite you to open an issue on our `Github issue tracker <https://github.com/DeltaRCM/pyDeltaRCM/issues>`_.
Please explain the problem as fully as possible, including any system information that may be relevant.

You can also ask any questions about the software or ask for help on the `Github issue tracker <https://github.com/DeltaRCM/pyDeltaRCM/issues>`_.
We will try our best to help you how we can!
